==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneHeaderConnectionEventArgsDetailDescription, _super);
    function WebPaneHeaderConnectionEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.h = null;
        return _this;
    }
    WebPaneHeaderConnectionEventArgsDetailDescription.prototype.get_type = function () {
        return "WebPaneHeaderConnectionEventArgsDetail";
    };
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDetailDescription.prototype, "pane", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Pane");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDetailDescription.prototype, "element", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("Element");
        },
        enumerable: true,
        configurable: true
    });
    WebPaneHeaderConnectionEventArgsDetailDescription.$t = markType(WebPaneHeaderConnectionEventArgsDetailDescription, 'WebPaneHeaderConnectionEventArgsDetailDescription', Description.$);
    WebPaneHeaderConnectionEventArgsDetailDescription.__marshalByValue = true;
    WebPaneHeaderConnectionEventArgsDetailDescription.__marshalByValueAlias = "PaneHeaderConnectionEventArgsDetail";
    return WebPaneHeaderConnectionEventArgsDetailDescription;
}(Description));
export { WebPaneHeaderConnectionEventArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneHeaderConnectionEventArgsDetailDescription, _super);
    function WebPaneHeaderConnectionEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.j = null;
        return _this;
    }
    WebPaneHeaderConnectionEventArgsDetailDescription.prototype.get_type = function () {
        return "WebPaneHeaderConnectionEventArgsDetail";
    };
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDetailDescription.prototype, "pane", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Pane");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDetailDescription.prototype, "element", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("Element");
        },
        enumerable: false,
        configurable: true
    });
    WebPaneHeaderConnectionEventArgsDetailDescription.$t = markType(WebPaneHeaderConnectionEventArgsDetailDescription, 'WebPaneHeaderConnectionEventArgsDetailDescription', Description.$);
    WebPaneHeaderConnectionEventArgsDetailDescription.__marshalByValue = true;
    WebPaneHeaderConnectionEventArgsDetailDescription.__marshalByValueAlias = "PaneHeaderConnectionEventArgsDetail";
    return WebPaneHeaderConnectionEventArgsDetailDescription;
}(Description));
export { WebPaneHeaderConnectionEventArgsDetailDescription };
